==> hornet-js-test-5.1.1.tgz: package/src/abstract-test.ts <==
/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */

/**
 * hornet-js-test - Ensemble des composants pour les tests hornet-js
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.1.1
 * @link git+https://github.com/diplomatiegouvfr/hornet-js.git
 * @license CECILL-2.1
 */

import * as React from "react";
import * as ReactDom from "react-dom";

import * as http from "http";
import * as https from "https";
/**
 * classe abstraite de Test
 */
export class AbstractTest {
    /**
     * Fonction de cloture du test
     **/
    protected endft: Function;

    /**
     * Fonction à appeler pour cloturer un test
     * @param {Error} err : err s'il en existe une
     **/
    public end(err?: Error) {
       
        if (http[ "__old_http_request" ] != undefined) {
            (http as any).request = http[ "__old_http_request" ];
            (https as any).request = https[ "__old_https_reques" ];
            delete http[ "__old_http_request" ];
            delete https[ "__old_https_reques" ];
        }


        this.endft(err);
    }

    /**
     * Fonction à appeler pour insérer un element dans le dom
     * @param {JSX.Element} element le composant react à insérer
     * @param {string} id l'identifiant du conteneur html dans lequel sera placé cet element
     **/
    public renderIntoDocument(element: React.ReactElement<any> , id: string) {
        if (typeof document !== "undefined"){
            let div = document.querySelector("#" + id);
            if (!div) {
                div = document.createElement("div");
                div.id = id;
                document.body.appendChild(div);
            }
            return ReactDom.render(element, div);
        }
    }

    /**
     * Fonction qui permet de catcher une exception pour un traitement asynchrone.
     * @param {any} done fonction de fin de test.
     **/
    public catchAsyncThrow(done: (any)) {
        // Remove Mocha's error listener
        if (typeof process !== "undefined" && process.listeners) {
            let originalErrorListeners = process.listeners("error");
            process.removeAllListeners("error");

            // Add your own error listener to check for unhandled exceptions
            process.on("error", function (e) {
                console.log("catchAsyncThrow", e);
                // Add the original error listeners again
                process.removeAllListeners("error");
                for (let i = 0; i < originalErrorListeners.length; i += 1) {
                    process.on("error", originalErrorListeners[ i ]);
                }
                // For the sake of simplicity we are done after catching the unhandled exception
                done();
            });
        }
    }

    /**
     * Fonction qui permet de lancer des évènements du dom
     * @param {domElement} node sur lequel on souhaite agir
     * @param {string} eventType le type d'évènement qu'on souhaite lancer
     **/
    public triggerMouseEvent(node, eventType: string) {
        let clickEvent = document.createEvent("MouseEvents");
        clickEvent.initEvent(eventType, true, true);
        node.dispatchEvent(clickEvent);
    }

}

==> hornet-js-test-5.2.0.tgz: package/src/abstract-test.ts <==
/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dga-dsi-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */

/**
 * hornet-js-test - Ensemble des composants pour les tests hornet-js
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.2.0
 * @link git+https://github.com/diplomatiegouvfr/hornet-js.git
 * @license CECILL-2.1
 */

import * as React from "react";
import * as ReactDom from "react-dom";

import * as http from "http";
import * as https from "https";
/**
 * classe abstraite de Test
 */
export class AbstractTest {
    /**
     * Fonction de cloture du test
     **/
    protected endft: Function;

    /**
     * Fonction à appeler pour cloturer un test
     * @param {Error} err : err s'il en existe une
     **/
    public end(err?: Error) {

        if (http[ "__old_http_request" ] !== undefined) {
            (http as any).request = http[ "__old_http_request" ];
            (https as any).request = https[ "__old_https_reques" ];
            delete http[ "__old_http_request" ];
            delete https[ "__old_https_reques" ];
        }


        this.endft(err);
    }

    /**
     * Fonction à appeler pour insérer un element dans le dom
     * @param {JSX.Element} element le composant react à insérer
     * @param {string} id l'identifiant du conteneur html dans lequel sera placé cet element
     **/
    public renderIntoDocument(element: React.ReactElement<any>, id: string) {
        if (typeof document !== "undefined") {
            let div = document.querySelector("#" + id);
            if (!div) {
                div = document.createElement("div");
                div.id = id;
                document.body.appendChild(div);
            }
            return ReactDom.render(element, div);
        }
    }

    /**
     * Fonction qui permet de catcher une exception pour un traitement asynchrone.
     * @param {any} done fonction de fin de test.
     **/
    public catchAsyncThrow(done: (any)) {
        // Remove Mocha's error listener
        if (typeof process !== "undefined" && process.listeners) {
            const originalErrorListeners = process.listeners("uncaughtException");
            process.removeAllListeners("error");
            process.removeAllListeners("uncaughtException");

            // Add your own error listener to check for unhandled exceptions
            process.on("uncaughtException", function (e) {
                console.log("catchAsyncThrow", e);
                // Add the original error listeners again
                process.removeAllListeners("uncaughtException");
                for (let i = 0; i < originalErrorListeners.length; i += 1) {
                    process.on("uncaughtException", originalErrorListeners[ i ]);
                }
                // For the sake of simplicity we are done after catching the unhandled exception
                done();
            });
        }
    }

    /**
     * Fonction qui permet de lancer des évènements du dom
     * @param {domElement} node sur lequel on souhaite agir
     * @param {string} eventType le type d'évènement qu'on souhaite lancer
     **/
    public triggerMouseEvent(node, eventType: string) {
        const clickEvent = document.createEvent("MouseEvents");
        clickEvent.initEvent(eventType, true, true);
        node.dispatchEvent(clickEvent);
    }

    /**
     * Méthode permettant de générer un id aléatoire unique
     */
    public generateMainId() {
        return `main${new Date().getTime()}`;
    }

}
